@@ -5,6 +5,7 @@ Created on Mon Sep 21 11:29:27 2020
 @author: Mai Tai
 """
 import panel.widgets
+import param
 import pyvisa
 from time import sleep
 
@@ -13,26 +14,43 @@ hwid = ["10C4:EA60"]
 serial_number = ["0001"]
 
 
-class instrument:
+class instrument(param.Parameterized):
     OnButton = panel.widgets.Button(name="On")
     OffButton = panel.widgets.Button(name="Off")
+    shutter = param.Boolean()
 
     def __init__(self, port):
+        super().__init__()
         rm = pyvisa.ResourceManager()
         current_port = port.name
         self.MaiTai = rm.open_resource(f'ASRL/dev/{current_port}::INSTR')
         self.MaiTai.baud_rate = 115200
         self.OnButton.on_click(self.On)
+        self.shutter = self.get_shutter()
         self.OffButton.on_click(self.Off)
+
+    @param.depends("shutter", watch=True)
     def Shutter(self, val=0):
         '''Returns print string'''
         if val == 1:
+            self.shutter = True
+            # print("Shutter Opened")
+        elif val == 0:
+            self.shutter = False
+            # print("Shutter Closed")
+        if self.shutter:
             self.MaiTai.write("SHUT 1")
             # print("Shutter Opened")
         else:
             self.MaiTai.write("SHUT 0")
             # print("Shutter Closed")
 
+    def get_shutter(self):
+        if self.MaiTai.query("SHUT?") == 1:
+            return True
+        else:
+            return False
+
     def Get_Wavelength(self):
         """Helper function for instrumental to avoid clutter and make code
         more readable
@@ -95,4 +113,4 @@ class instrument:
         return status_byte
 
     def widgets(self):
-        return panel.Column(self.OffButton, self.OnButton)
+        return panel.Column(self.OffButton, self.OnButton,self.param)
