@@ -23,5 +23,5 @@ def find_ports():
 
 def port_table():
     ports = find_ports()
-    table = [[port.hwid, port.serial_number, port,port.hwid.split(" ")[1].replace("VID:PID=","")] for port in ports]
-    print(tabulate(table,headers=["hwid(full)","serial_number","port","hwid"]))
+    table = [[port.hwid, port.serial_number, port,port.hwid.split(" ")[1].replace("VID:PID=",""),port.name] for port in ports]
+    print(tabulate(table,headers=["hwid(full)","serial_number","port","hwid","tty"]))
